@@ -22,7 +22,6 @@ __docformat__ = "restructuredtext en"
 from warnings import warn
 
 from logilab.common import attrdict
-from logilab.common.compat import sorted
 from logilab.common.decorators import iclassmethod
 
 from yams import BASE_TYPES, MARKER, BadSchemaDefinition
@@ -668,7 +667,9 @@ for basetype in BASE_TYPES:
 
 
 class RichString(String):
-    """Convenience RichString attribute type
+    """RichString is a convenience attribute type for attribute containing text
+    in a format that should be specified in another attribute.
+
     The following declaration::
 
       class Card(EntityType):
