@@ -29,7 +29,6 @@ from os import listdir
 from os.path import exists, join, splitext, basename, abspath
 from warnings import warn
 
-from logilab.common.testlib import mock_object
 from logilab.common.modutils import modpath_from_file, cleanup_sys_modules
 
 from yams import UnknownType, BadSchemaDefinition, BASE_TYPES
@@ -334,5 +333,8 @@ class SchemaLoader(object):
             hdlr.error('invalid definition object')
         defobject.expand_type_definitions(self.defined)
 
+class _Context(object):
+    def __init__(self):
+        self.defined = {}
 
-context = mock_object(defined={})
+context = _Context()
