@@ -25,7 +25,6 @@ from decimal import Decimal
 
 from logilab.common import attrdict
 from logilab.common.decorators import cached, clear_cache
-from logilab.common.compat import sorted
 from logilab.common.interface import implements
 from logilab.common.deprecation import deprecated
 
@@ -849,7 +848,7 @@ class RelationSchema(ERSchema):
         try:
             return tuple(self._obj_schemas[etype])
         except KeyError:
-            raise KeyError("%s don't have %s as object" % (self, etype))
+            raise KeyError("%s does not have %s as object" % (self, etype))
 
     def objects(self, etype=None):
         """Return a list of entity schema which can be object of this relation.
@@ -864,7 +863,7 @@ class RelationSchema(ERSchema):
         try:
             return tuple(self._subj_schemas[etype])
         except KeyError:
-            raise KeyError("%s don't have %s as subject" % (self, etype))
+            raise KeyError("%s does not have %s as subject" % (self, etype))
 
     def targets(self, etype=None, role='subject'):
         """return possible target types with <etype> as <x>"""
